============================
Django Rest Framework Braces
============================

Contents
--------

.. toctree::
   :maxdepth: 2

   overview
   contributing
   authors
   history

.. include:: ../README.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
